# fsdviewer

simple 2d viewer for formula student driverless software

![](imgs/img1.jpg)

## Features 

- Draw cones(circles) in multiple colors and sizes
- Draw Multiple Cars
- Draw lines between cones
- Draw lines between lines

![](imgs/gif.gif)